==========
PyMongoLab
==========
:Info: See `PyMongoLab documentation site`_ for more information. See `GitHub repository`_ for the latest source.
:Author: Jorge Puente Sarrín <puentesarrin@gmail.com>

About
=====

PyMongoLab is a Python_ client library that contains tools for accessing to
MongoLab databases via the `MongoLab REST API`_ using a similar syntax to PyMongo_.
Useful in cases where network barriers (firewalls, etc.)  prevent use of the
standard MongoDB driver.

>>> from pymongolab import MongoClient
>>> con = MongoClient("MongoLabAPIKey")
>>> db = con.database
>>> col = db.collection.find()
>>> list(col)
[{u'_id': ObjectId('50243d38e4b00c3b3e75fc94'), u'foo': u'bar', u'tld': u'com'},
{u'_id': ObjectId('50004d646cf431171ed53846'), u'foo': u'bar', u'tld': u'org'}]

Documentation
=============

Sphinx_ must be installed to generate the documentation. Documentation can be
generated by running **python setup.py doc**.

.. _Python: http:www.python.org
.. _PyMongoLab documentation site: http://pymongolab.puentesarr.in
.. _GitHub repository: https://github.com/puentesarrin/pymongolab/tree
.. _MongoLab REST API: http://support.mongolab.com/entries/20433053-rest-api-for-mongodb
.. _PyMongo: http://api.mongodb.org/python/current/
.. _Sphinx: http://sphinx.pocoo.org/
